# senseid

[![PyPI - Version](https://img.shields.io/pypi/v/senseid.svg)](https://pypi.org/project/senseid)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/senseid.svg)](https://pypi.org/project/senseid)

-----

## Table of Contents

- [Installation](#installation)
- [License](#license)

## Installation

```console
pip install senseid
```

## License

`senseid` is distributed under the terms of the [MIT](https://spdx.org/licenses/MIT.html) license.
